Registrable

Trait Registrable 

pub trait Registrable:
    Serialize
    + DeserializeOwned
    + Send
    + Sync {
    // Required method
    fn kind() -> MeshKind;
}
Trait for mesh types that can be registered in a namespace.

This trait is implemented for HostMeshRef, ProcMeshRef, and ActorMeshRef<A>, allowing them to be registered and looked up using the generic register and get methods on Namespace.

Required Methods

fn kind() -> MeshKind

The kind of mesh this type represents.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors